@@ -66,6 +66,7 @@ class ExplorerWidget(QtGui.QWidget):
 	def bind(self):
 		# Search
 		QtCore.QObject.connect(self.ui.searchFolder,QtCore.SIGNAL("returnPressed()"),self.slotSearchFolder)
+		QtCore.QObject.connect(self.ui.searchButton,QtCore.SIGNAL("clicked()"),self.slotSearchFolder)
 		# Tree View
 		QtCore.QObject.connect(self.ui.treeView,QtCore.SIGNAL("clicked(QModelIndex)"),self.slotTreeViewClick)
 		QtCore.QObject.connect(self.ui.treeView,QtCore.SIGNAL("doubleClicked(QModelIndex)"),self.slotTreeViewDoubleClick)
@@ -405,7 +406,10 @@ class ExplorerWidget(QtGui.QWidget):
 			for k,v in myactions.items():
 				if len(myactions[k])>2:
 					icon = QtGui.QIcon()
-					icon.addPixmap(QtGui.QPixmap(_fromUtf8(":/rPrj/%s"%myactions[k][2])), QtGui.QIcon.Normal, QtGui.QIcon.Off)
+					# 2012.10.16: start.
+					icon.addPixmap(QtGui.QPixmap(_fromUtf8(":/rPrj/icons/%s"%myactions[k][2])), QtGui.QIcon.Normal, QtGui.QIcon.Off)
+					#icon.addPixmap(QtGui.QPixmap(_fromUtf8(":/rPrj/%s"%myactions[k][2])), QtGui.QIcon.Normal, QtGui.QIcon.Off)
+					# 2012.10.16: end.
 					myaction = menuActions.addAction(icon,QtGui.QApplication.translate("TreeView", myactions[k][0], None, QtGui.QApplication.UnicodeUTF8),self.slotCustomAction)
 				else:
 					myaction = menuActions.addAction(QtGui.QApplication.translate("TreeView", myactions[k][0], None, QtGui.QApplication.UnicodeUTF8),self.slotCustomAction)
