@@ -394,7 +394,7 @@ class FDateTime(FField,rprj.formulator.FDateTime):
 		if not self.field is None:
 			if v is None:
 				self.field.setDateTime(QtCore.QDateTime.fromString('2000-01-01 00:00:00',"yyyy-MM-dd hh:mm:ss"))
-			elif type(v)==str:
+			elif type(v)==str or type(v)==unicode:
 				self.field.setDateTime(QtCore.QDateTime.fromString(v,"yyyy-MM-dd hh:mm:ss"))
 			elif isinstance(v,datetime.time):
 				# TODO show only time for timetracks
@@ -556,7 +556,100 @@ class FUuid(FString,rprj.formulator.FUuid):
 		if not self.field is None:
 			self.field.setText(__v)
 class FPermissions(FField): #,rprj.formulator.FPermissions):
-	pass
+	def __init__(self, aNomeCampo, aTitle, aDescription, aSize, aLength=20, aValore='', aClasseCss=None, myform=None, mytipo='s'):
+		QtCore.QObject.__init__(self)
+		rprj.formulator.FField.__init__(self, aNomeCampo, aTitle, aDescription, aSize, aLength=20, aValore='', aClasseCss=None, myform=None, mytipo='s')
+		self.widget = None
+		self.label = None
+		self.field = None
+	def getValue(self):
+		v=[ '-', '-', '-', '-', '-', '-', '-', '-', '-' ]
+		if self.buttonUserRead.isChecked(): v[0]='r'
+		if self.buttonUserWrite.isChecked(): v[1]='w'
+		if self.buttonUserExecute.isChecked(): v[2]='x'
+		if self.buttonGroupRead.isChecked(): v[3]='r'
+		if self.buttonGroupWrite.isChecked(): v[4]='w'
+		if self.buttonGroupExecute.isChecked(): v[5]='x'
+		if self.buttonAllRead.isChecked(): v[6]='r'
+		if self.buttonAllWrite.isChecked(): v[7]='w'
+		if self.buttonAllExecute.isChecked(): v[8]='x'
+		self.aValore = "".join(v)
+		return self.aValore
+	def setValue(self,v, update_widget=True):
+		if len(v)<9:
+			v = "%s%s" % (v, '-' * (9-len(v)) )
+		self.aValore = v
+		self.buttonUserRead.setChecked( v[0]=='r' )
+		self.buttonUserWrite.setChecked( v[1]=='w' )
+		self.buttonUserExecute.setChecked( v[2]=='x' )
+		self.buttonGroupRead.setChecked( v[3]=='r' )
+		self.buttonGroupWrite.setChecked( v[4]=='w' )
+		self.buttonGroupExecute.setChecked( v[5]=='x' )
+		self.buttonAllRead.setChecked( v[6]=='r' )
+		self.buttonAllWrite.setChecked( v[7]=='w' )
+		self.buttonAllExecute.setChecked( v[8]=='x' )
+	def InitField(self,parent):
+		self.field = QtGui.QWidget(parent)
+		self.field.setObjectName("field_%s"%self.aNomeCampo)
+		self.fieldLayout = QtGui.QGridLayout(self.field)
+		self.fieldLayout.setMargin(0)
+		self.fieldLayout.setObjectName("field_layout_%s"%self.aNomeCampo)
+		# Buttons
+		col = 0
+		self.userLabel = QtGui.QLabel("User", self.field)
+		self.fieldLayout.addWidget(self.userLabel, 0, col+0,  1, 3, QtCore.Qt.AlignHCenter)
+		self.buttonUserRead = QtGui.QToolButton(self.field)
+		self.buttonUserRead.setText("R")
+		self.buttonUserRead.setToolTip("Read")
+		self.buttonUserRead.setCheckable(True)
+		self.fieldLayout.addWidget(self.buttonUserRead, 1, col+0)
+		self.buttonUserWrite = QtGui.QToolButton( self.field)
+		self.buttonUserWrite.setText("W")
+		self.buttonUserWrite.setCheckable(True)
+		self.buttonUserWrite.setToolTip("Write")
+		self.fieldLayout.addWidget(self.buttonUserWrite, 1, col+1)
+		self.buttonUserExecute = QtGui.QToolButton( self.field)
+		self.buttonUserExecute.setText("X")
+		self.buttonUserExecute.setCheckable(True)
+		self.buttonUserExecute.setToolTip("Execute")
+		self.fieldLayout.addWidget(self.buttonUserExecute, 1, col+2)
+		col += 3
+		self.groupLabel = QtGui.QLabel("Group", self.field)
+		self.fieldLayout.addWidget(self.groupLabel, 0, col+0,  1, 3, QtCore.Qt.AlignHCenter)
+		self.buttonGroupRead = QtGui.QToolButton(self.field)
+		self.buttonGroupRead.setText("R")
+		self.buttonGroupRead.setToolTip("Read")
+		self.buttonGroupRead.setCheckable(True)
+		self.fieldLayout.addWidget(self.buttonGroupRead, 1, col+0)
+		self.buttonGroupWrite = QtGui.QToolButton(self.field)
+		self.buttonGroupWrite.setText("W")
+		self.buttonGroupWrite.setCheckable(True)
+		self.buttonGroupWrite.setToolTip("Write")
+		self.fieldLayout.addWidget(self.buttonGroupWrite, 1, col+1)
+		self.buttonGroupExecute = QtGui.QToolButton(self.field)
+		self.buttonGroupExecute.setText("X")
+		self.buttonGroupExecute.setCheckable(True)
+		self.buttonGroupExecute.setToolTip("Execute")
+		self.fieldLayout.addWidget(self.buttonGroupExecute, 1, col+2)
+		col += 3
+		self.allLabel = QtGui.QLabel("All", self.field)
+		self.fieldLayout.addWidget(self.allLabel, 0, col+0,  1, 3, QtCore.Qt.AlignHCenter)
+		self.buttonAllRead = QtGui.QToolButton(self.field)
+		self.buttonAllRead.setText("R")
+		self.buttonAllRead.setToolTip("Read")
+		self.buttonAllRead.setCheckable(True)
+		self.fieldLayout.addWidget(self.buttonAllRead, 1, col+0)
+		self.buttonAllWrite = QtGui.QToolButton(self.field)
+		self.buttonAllWrite.setText("W")
+		self.buttonAllWrite.setCheckable(True)
+		self.buttonAllWrite.setToolTip("Write")
+		self.fieldLayout.addWidget(self.buttonAllWrite, 1, col+1)
+		self.buttonAllExecute = QtGui.QToolButton(self.field)
+		self.buttonAllExecute.setText("X")
+		self.buttonAllExecute.setCheckable(True)
+		self.buttonAllExecute.setToolTip("Execute")
+		self.fieldLayout.addWidget(self.buttonAllExecute, 1, col+2)
+		return self.field
 class FLanguage(FField): #,rprj.formulator.FLanguage):
 	pass
 class FChildSort(FList): #,rprj.formulator.FChildSort):
